'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ButtonGroup = exports.ButtonGroupColors = exports.ButtonGroupSizes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Button group size enumerable.
 *
 * @type {{TINY: string, SMALL: string, LARGE: string}}
 */
var ButtonGroupSizes = exports.ButtonGroupSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Button group color enumerable.
 *
 * @type {{PRIMARY: string, SECONDARY: string, SUCCESS: string, ALERT: string, WARNING: string}}
 */
var ButtonGroupColors = exports.ButtonGroupColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  ALERT: 'alert',
  WARNING: 'warning'
};

/**
 * Button group component.
 * http://foundation.zurb.com/sites/docs/button-group.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var ButtonGroup = exports.ButtonGroup = function ButtonGroup(props) {
  var className = (0, _utils.createClassName)(props.className || 'button-group', props.color, props.size, {
    'expanded': props.isExpanded,
    'stacked': props.isStacked,
    'stacked-for-small': props.stackedForSmall,
    'stacked-for-medium': props.stackedForMedium,
    'stacked-for-large': props.stackedForLarge
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, (0, _utils.removeProps)(props, ['color']), { className: className }));
};

ButtonGroup.propTypes = _extends({
  color: _react.PropTypes.oneOf((0, _utils.objectValues)(ButtonGroupColors)),
  size: _react.PropTypes.oneOf((0, _utils.objectValues)(ButtonGroupSizes)),
  isExpanded: _react.PropTypes.bool,
  stackedForSmall: _react.PropTypes.bool,
  stackedForMedium: _react.PropTypes.bool,
  stackedForLarge: _react.PropTypes.bool
}, _utils.GeneralPropTypes);