'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuText = exports.MenuItem = exports.Menu = exports.MenuAlignments = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Menu alignment enumerable.
 *
 * @type {{RIGHT: string, CENTER: string}}
 */
var MenuAlignments = exports.MenuAlignments = {
  RIGHT: 'right',
  CENTER: 'center'
};

/**
 * Menu component.
 * http://foundation.zurb.com/sites/docs/menu.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var Menu = exports.Menu = function Menu(props) {
  var className = (0, _utils.createClassName)(props.className || 'menu', {
    'align-right': props.alignment === MenuAlignments.RIGHT,
    'align-center': props.alignment === MenuAlignments.CENTER,
    'icon-top': props.iconsOnTop,
    'expanded': props.isExpanded,
    'vertical': props.isVertical,
    'simple': props.isSimple,
    'nested': props.isNested
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('ul', _extends({}, props, { className: className }));
};

Menu.propTypes = _extends({
  alignment: _react.PropTypes.oneOf((0, _utils.objectValues)(MenuAlignments)),
  iconsOnTop: _react.PropTypes.bool,
  isExpanded: _react.PropTypes.bool,
  isVertical: _react.PropTypes.bool,
  isSimple: _react.PropTypes.bool,
  isNested: _react.PropTypes.bool
}, _utils.GeneralPropTypes);

/**
 * Menu item component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var MenuItem = exports.MenuItem = function MenuItem(props) {
  var className = (0, _utils.createClassName)(props.className, {
    'active': props.isActive
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('li', _extends({}, props, { className: className }));
};

MenuItem.propTypes = _extends({
  isActive: _react.PropTypes.bool
}, _utils.GeneralPropTypes);

/**
 * Menu text wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var MenuText = exports.MenuText = function MenuText(props) {
  return _react2.default.createElement(MenuItem, _extends({}, props, { className: props.className || 'menu-text' }));
};